import pytest


def pytest_addoption(parser):
    parser.addoption(
        "--integration",
        metavar="LIVY_URL",
        nargs="?",
        const="http://localhost:8998",
        help="Run integration tests against the specified Livy server URL "
        + "(default: http://localhost:8998)",
    )


def pytest_configure(config):
    config.addinivalue_line(
        "markers", "integration: mark test as integration test"
    )


def pytest_collection_modifyitems(config, items):
    if config.getoption("--integration") is not None:
        # --integration given in cli: do not skip slow tests
        return
    skip = pytest.mark.skip(reason="Add --integration option to run")
    for item in items:
        if "integration" in item.keywords:
            item.add_marker(skip)


@pytest.fixture
def integration_url(request):
    return request.config.getoption("--integration")



# Configuration file for the Sphinx documentation builder.


# -- Project information -----------------------------------------------------

project = "pylivy"
copyright = "2018-2020, Andrew Crozier"
author = "Andrew Crozier"


# -- General configuration ---------------------------------------------------

extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.viewcode",
    "sphinx_autodoc_typehints",
]

# Order class method documentation according to their order in source code
autodoc_member_order = "bysource"


# -- Options for HTML output -------------------------------------------------

html_theme = "alabaster"

html_theme_options = {
    "description": "Use Apache Livy from Python.",
    "github_user": "acroz",
    "github_repo": "pylivy",
}
